@@ -1,6 +1,7 @@
+from dataclasses import dataclass
 from typing import Optional, Tuple
 
-from pytoolconfig import UniversalKey, dataclass, field
+from pytoolconfig import UniversalKey, field
 from pytoolconfig.documentation import _type_to_str, _write_model
 
 
@@ -11,7 +12,7 @@ class SubTool:
 
 @dataclass
 class NestedModel:
-    subtool: SubTool = SubTool()
+    subtool: SubTool = field(default_factory=lambda: SubTool())
     foo_other: Optional[str] = field(
         description="Tool One", default="no", command_line=("--foo", "-f")
     )
@@ -34,5 +35,5 @@ def test_documentation():
     assert "foo_other" in lines[3]
     assert "Tool One" in lines[3]
     assert "no" in lines[3]
-    assert "Optional" in lines[3]
+    assert "str" in lines[3]
     assert "bool" in lines[5]
